@@ -86,8 +86,10 @@ static inline unsigned int keyHashSlot(const char *key, int keylen) {
 /* functions requiring mechanism specific implementations */
 void clusterInit(void);
 void clusterInitLast(void);
+void clusterCommonInit(void);
 void clusterCron(void);
 void clusterBeforeSleep(void);
+void clusterClaimUnassignedSlots(void);
 int verifyClusterConfigWithData(void);
 
 int clusterSendModuleMessageToTarget(const char *target, uint64_t module_id, uint8_t type, const char *payload, uint32_t len);
@@ -189,6 +191,7 @@ slotRangeArray *slotRangeArrayDup(slotRangeArray *slots);
 void slotRangeArraySet(slotRangeArray *slots, int idx, int start, int end);
 sds slotRangeArrayToString(slotRangeArray *slots);
 slotRangeArray *slotRangeArrayFromString(sds data);
+void slotRangeArraySortAndMerge(slotRangeArray *slots);
 int slotRangeArrayIsEqual(slotRangeArray *slots1, slotRangeArray *slots2);
 slotRangeArray *slotRangeArrayAppend(slotRangeArray *slots, int slot);
 int slotRangeArrayContains(slotRangeArray *slots, unsigned int slot);
@@ -198,7 +201,7 @@ slotRangeArrayIter *slotRangeArrayGetIterator(slotRangeArray *slots);
 int slotRangeArrayNext(slotRangeArrayIter *it);
 int slotRangeArrayGetCurrentSlot(slotRangeArrayIter *it);
 void slotRangeArrayIteratorFree(slotRangeArrayIter *it);
-int validateSlotRanges(slotRangeArray *slots, sds *err);
+int slotRangeArrayNormalizeAndValidate(slotRangeArray *slots, sds *err);
 slotRangeArray *parseSlotRangesOrReply(client *c, int argc, int pos);
 
 unsigned int clusterDelKeysInSlot(unsigned int hashslot, int by_command);
